@@ -1,4 +1,5 @@
 # add.pl: main routine for dcbib-add(1).
+# $Id: add.pl,v 1.3 1999/05/18 12:47:51 toyoda Exp $
 # Copyright (c) TOYODA Eizi, 1998.  All rights reserved.
 # see COPYING.TXT for terms of license.
 
@@ -16,7 +17,7 @@ while ($_ = shift) {
 	&emlSetFile("STDIN");
 	%HEADER = &emlRead();
 
-	&testCard;
+	&testCard(\%HEADER);
 
 	$outfnam = &generateFileName;
 	&creat($outfnam);
